#!/usr/local/bin/perl -w

# convert output from SensevalClassify.java from a distributional
# format to one where the most probable class is output

# Copyright (C) 2000-2001
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Satanjeev Banerjee, University of Minnesota, Duluth
# bane0025@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#-----------------------------------------------------------------------------
#                              Start of program
#-----------------------------------------------------------------------------

# we have to use commandline options, so use the necessary package!
use Getopt::Long;

# first check if no commandline options have been provided... in which case
# print out the usage notes!
if ( $#ARGV == -1 )
{
    &minimalUsageNotes();
    exit;
}

# now get the options!
GetOptions("version", "help", "margin=f" );

# if help has been requested, print out help!
if ( defined $opt_help )
{
    $opt_help = 1;
    &showHelp();
    exit;
}

# if version has been requested, show version!
if ( defined $opt_version )
{
    $opt_version = 1;
    &showVersion();
    exit;
}

# if margin has been defined, note it. else use default
$margin = (defined $opt_margin) ? ($opt_margin) : 0;

while (<>)
{
    %array = ();
    ($item, $instance, @senses) = split(/\s+/);
    
    print "$item $instance";
    
    foreach (@senses) 
    {
	($def,$prob) = split (/\//,$_);
	$array{$def} = $prob;
    }
    
    $count = 0;
    foreach (sort { $array{$b} cmp $array{$a} } keys %array) 
    {
	if ($count == 0) 
	{
	    $max = $array{$_};
	    print " $_";
	}
	
	elsif (($max - $array{$_}) <= $margin)
	{
	    print " $_";
	}
	$count++;
    }
    print "\n";
}

# function to output a minimal usage note when the user has not provided any
# commandline options
sub minimalUsageNotes
{
    print "Usage: winnerTakeAll.pl [OPTIONS] SOURCE [[, SOURCE] ...]\n";
    askHelp();
}

# function to output help messages for this program
sub showHelp
{
    print "Usage: winnerTakeAll.pl [OPTIONS] SOURCE [[, SOURCE] ...]\n";
    print "Converts output from SensevalClassify.java from a distributional format to\n";
    print "one where the most probable class is output.\n\n";
    print "OPTIONS:\n\n";
    print "  --version          Prints the version number.\n\n";
    print "  --help             Prints this help message.\n\n";
    print "  --margin NUMBER    If two or more senses have probability values differing\n";
    print "                     by less than or equal to NUMBER, then they are considered\n";
    print "                     equally probable\n\n";
}

# function to output the version number
sub showVersion
{
    print "winnerTakeAll.pl  -  Version 0.1\n";
    print "A component of the SenseTools Version 0.1\n";
    print "Copyright (C) 2000-2001, Ted Pedersen & Satanjeev Banerjee\n";
}

# function to output "ask for help" message when the user's goofed up!
sub askHelp
{
    print "Type winnerTakeAll.pl --help for help.\n";
}


