#!/usr/local/bin/perl -w

# program to convert a Senseval xml answer file into a answer-key as
# input to the scorer2 scoring program.

# Copyright (C) 2001
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Satanjeev Banerjee, University of Minnesota, Duluth
# bane0025@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#-----------------------------------------------------------------------------
#                              Start of program
#-----------------------------------------------------------------------------

# Programming notes: 

# format of input:
# <lexelt item="art.n">
# <instance id="art.40001" docsrc="bnc_ACN_245">
# <answer instance="art.40001" senseid="art~1:06:00::"/>
  
# format of output:
# art art.30001 art_dealer~1:18:00::
  					      
# new version of xml2key by tdp june 13, 2001
#
# will handle both spanish and english format of senseval 2 data
# spanish uses numbers while english uses a mixture of alphanumeric
# this code simply finds what is inside of the senseid string
# and prints it.


# we have to use commandline options, so use the necessary package!
use Getopt::Long;

# first check if no commandline options have been provided... in which case
# print out the usage notes!
if ( $#ARGV == -1 )
{
    &minimalUsageNotes();
    exit;
}

# now get the options!
GetOptions("version", "help");

# if help has been requested, print out help!
if ( defined $opt_help )
{
    $opt_help = $opt_help;
    &showHelp();
    exit;
}

# if version has been requested, show version!
if ( defined $opt_version )
{
    $opt_version = $opt_version;
    &showVersion();
    exit;
}

$new = 0;
$first=0;
while (<>) {
	if (/<lexelt\s+item="(\S+)"/) {
		$lexelt=$1;
	}
	elsif (/<instance\s+id="(\S+)"/) {
		$instance=$1;
		$first = 0;
		if ($new == 1) {
			print "\n";
		}
	}
	elsif (/<answer.*senseid="(\S+)"/) {
		if ($first == 0) {
			$new = $first = 1;
			
			print "$lexelt $instance $1 ";
			
		}
		else {
			print "$1 ";	
		}
	}
}
print "\n";

# thats it!

# function to output a minimal usage note when the user has not provided any
# commandline options
sub minimalUsageNotes
{
    print "Usage: xml2key.pl [OPTIONS] SOURCE\n";
    askHelp();
}

# function to output help messages for this program
sub showHelp
{
    print "Usage: xml2key.pl [OPTIONS] SOURCE\n\n";

    print "Creates a key file from SOURCE Senseval lexical sample file.\n\n";

    print "OPTIONS:\n\n";

    print "  --version          Prints the version number.\n\n";

    print "  --help             Prints this help message.\n\n";
}

# function to output the version number
sub showVersion
{
    print "xml2key.pl  -  Version 0.1\n";
    print "A component of SenseTools 0.1\n";
    print "Copyright (C) 2001, Ted Pedersen & Satanjeev Banerjee\n";
}

# function to output "ask for help" message when the user's goofed up!
sub askHelp 
{
    print STDERR "Type xml2key.pl --help for help.\n";
}
